# Django package imports.
from django.conf.urls import include
from django.conf.urls import url
from django.utils.timezone import now

# Local package imports.
from . import views as views


# The index page for this web application.
index = url(r'^$', views.Index.as_view(), name = 'nmcc_ziamet_index')

# A page that shows the status of the ZiaMet network.
status = url(r'^status/$', views.Status.as_view(), name = 'nmcc_ziamet_status')

# The station index page.  The jumping off point for more station 
# data and metadata products.
station_index = url(r'^station/(?P<station_id>[^/]+)/$', 
    views.StationIndex.as_view(), 
    name = 'nmcc_ziamet_station_index')

# A URL for requesting a timeseries for the given station over a given 
# date range.
station_timeseries = url(r'^station/(?P<station_id>[^/]+)/' + \
    '(?P<frequency_id>[^/]+)/data/' + \
    'from/(?P<start_date>[^/]+)/to/(?P<end_date>[^/]+)/' + \
    'units/(?P<units>[^/]+)/' + \
    'output/(?P<output>[^/]+)/' + \
    'tz/(?P<time_zone>[^/]+)/$', 
    views.StationTimeseries.as_view(), 
    name = 'nmcc_ziamet_station_timeseries')

# A page containing hourly data for today only, for the given station.
station_timeseries_for_today = url(r'^station/(?P<station_id>[^/]+)/' + \
    'hourly/data/for/today/', 
    views.StationTimeseriesForToday.as_view(), 
    name = 'nmcc_ziamet_station_timeseries_for_today')

# A URL for requesting some number of days of the most recent data for 
# a given station.
station_timeseries_prev = url(r'^station/(?P<station_id>[^/]+)/' + \
    '(?P<frequency_id>[^/]+)/data/' + \
    'previous/(?P<prev_days>[^/]+)/days/' + \
    'units/(?P<units>[^/]+)/' + \
    'output/(?P<output>[^/]+)/' + \
    'tz/(?P<time_zone>[^/]+)/$', 
    views.StationTimeseriesPrev.as_view(), 
    name = 'nmcc_ziamet_station_timeseries_previous')

# A page that contains a request form for requesting a timeseries for 
# a given station.
station_request_timeseries = \
    url(r'^request/station/(?P<station_id>[^/]+)/data/$', 
    views.StationRequestTimeseries.as_view(), 
    name = 'nmcc_ziamet_station_request_timeseries')

# A URL for requesting a reference ET and GDD timeseries for the given 
# station over a given date range.  Daily data only.
station_daily_rg_timeseries = url(r'^station/(?P<station_id>[^/]+)/' + \
    'etref/gdd/data/' + \
    'from/(?P<start_date>[^/]+)/to/(?P<end_date>[^/]+)/' + \
    'units/(?P<units>[^/]+)/' + \
    'output/(?P<output>[^/]+)/' + \
    'tz/(?P<time_zone>[^/]+)/' + \
    'gdd/tbase/(?P<gdd_tbase>[^/]+)/' + \
    'tmaxcutoff/(?P<gdd_tmaxcutoff>[^/]+)/' + \
    'tmincutoff/(?P<gdd_tmincutoff>[^/]+)/' + \
    'cgdd/offset/(?P<cgdd_offset>[^/]+)/$', 
    views.StationRGTimeseries.as_view(), 
    name = 'nmcc_ziamet_station_rg_timeseries')

# A URL for requesting some number of days of the most recent reference 
# ET and GDD data for a given station.  Daily data only.
station_daily_rg_timeseries_prev = url(
    r'^station/(?P<station_id>[^/]+)/' + \
    'etref/gdd/data/' + \
    'previous/(?P<prev_days>[^/]+)/days/' + \
    'units/(?P<units>[^/]+)/' + \
    'output/(?P<output>[^/]+)/' + \
    'tz/(?P<time_zone>[^/]+)/' + \
    'gdd/tbase/(?P<gdd_tbase>[^/]+)/' + \
    'tmaxcutoff/(?P<gdd_tmaxcutoff>[^/]+)/' + \
    'tmincutoff/(?P<gdd_tmincutoff>[^/]+)/' + \
    'cgdd/offset/(?P<cgdd_offset>[^/]+)/$', 
    views.StationRGTimeseriesPrev.as_view(), 
    name = 'nmcc_ziamet_station_rg_timeseries_previous')

# A page that contains a request form for requesting a daily 
# timeseries of reference ET and GDD data for a given station.
station_request_daily_rg_timeseries = url(r'^request/station/' + \
    '(?P<station_id>[^/]+)/etref/gdd/data/$', 
    views.StationRequestRGTimeseries.as_view(), 
    name = 'nmcc_ziamet_station_request_rg_timeseries')

# Add all the above patterns to the 'urlpatterns' list.  These are the 
# the patterns available for this web application.
urlpatterns = [index, 
    status, 
    station_index, 
    station_timeseries, 
    station_timeseries_for_today, 
    station_timeseries_prev, 
    station_request_timeseries, 
    station_daily_rg_timeseries, 
    station_daily_rg_timeseries_prev, 
    station_request_daily_rg_timeseries]


